@@ -1,8 +1,9 @@
 #include <QtGui>
 #include "videoplayer.h"
 #include <QMaemo5InformationBox>
-#include <QDBusConnection>
-#include <QDBusInterface>
+#include <QtGui/QX11Info>
+#include <X11/Xlib.h>
+#include <X11/Xatom.h>
 
 VideoPlayer::VideoPlayer(bool login, QWidget *parent) :
     QMainWindow(parent)
@@ -163,7 +164,6 @@ VideoPlayer::VideoPlayer(bool login, QWidget *parent) :
     isCommentShown = false;
     showFullScreen();
     recentWVideos = settings.value("recentlyWatched", QStringList()).toStringList();
-    keepScreenOn();
 }
 
 void VideoPlayer::toolbarSwitch()
@@ -499,6 +499,7 @@ void VideoPlayer::stateChanged(Phonon::State newState, Phonon::State oldState)
                     }
                     emit playerReady();
                 }
+                doNotDisturb(true);
                 break;
         case Phonon::StoppedState:
                 playAction->setVisible(true);
@@ -506,6 +507,7 @@ void VideoPlayer::stateChanged(Phonon::State newState, Phonon::State oldState)
                 timeLcd->setText("00:00");
                 break;
         case Phonon::PausedState:
+                doNotDisturb(false);
                 pauseAction->setVisible(false);
                 stopAction->setVisible(true);
                 playAction->setVisible(true);
@@ -523,9 +525,12 @@ void VideoPlayer::popupMessage(const QString &message)
     QMaemo5InformationBox::information(this, message);
 }
 
-void VideoPlayer::keepScreenOn()
+void VideoPlayer::doNotDisturb(bool b)
 {
-    QDBusInterface iface("com.nokia.mce", "/com/nokia/mce/request", "com.nokia.mce.request", QDBusConnection::systemBus(), this);
-    iface.call("req_display_blanking_pause");
-    QTimer::singleShot(9000, this, SLOT(keepScreenOn()));
+    quint32 enable = 0;
+    if (b){
+        enable = 1;
+    }
+    Atom win = XInternAtom(QX11Info::display(), "_HILDON_DO_NOT_DISTURB", false);
+    XChangeProperty(QX11Info::display(), winId(), win, XA_INTEGER, 32, PropModeReplace, (uchar*) &enable, 1);
 }
